#
# spec file for package patterns-microos
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%bcond_with betatest

Name:           patterns-microos
Version:        5.0
Release:        84.1
Summary:        Patterns for openSUSE MicroOS
License:        MIT
Group:          Metapackages
URL:            http://en.opensuse.org/Patterns
Source0:        %name.rpmlintrc
ExclusiveArch:  x86_64 %arm32 aarch64 ppc64le s390x riscv64

%description
This is an internal package that is used to create the patterns as part
of the installation source setup. Installation of this package does
not make sense.

%package basesystem
Summary:        openSUSE MicroOS Base System (alias pattern for microos_base)
Group:          Metapackages
Provides:       pattern() = basesystem
Provides:       pattern-icon() = pattern-kubic
Requires:       pattern() = microos_base

%description basesystem
This is the openSUSE MicroOS runtime system. It contains only a minimal multiuser
booting system.

%package base
Summary:        openSUSE MicroOS
Group:          Metapackages
Provides:       pattern() = microos_base
Provides:       pattern-category() = MicroOS
Provides:       pattern-icon() = pattern-kubic
Provides:       pattern-order() = 9010
Provides:       pattern-visible()
Requires:       pattern() = minimal_base
%if %{with betatest}
# need to require it as recommends are off
Requires:       pattern() = update_test
%endif
### openSUSE base system
Requires:       /usr/bin/hostname
Requires:       aaa_base
Requires:       bash
Requires:       branding-openSUSE
Requires:       btrfsprogs
Requires:       ca-certificates
Requires:       ca-certificates-mozilla
Requires:       coreutils
Requires:       coreutils-systemd
Requires:       glibc
Requires:       (grub2-branding-openSUSE if grub2)
### Packages formerly provided by bootloader
Requires:       (grub2-snapper-plugin if grub2)
###
Suggests:       busybox-hostname
Requires:       NetworkManager
Requires:       NetworkManager-bluetooth
Requires:       NetworkManager-wifi
Requires:       build-key
Requires:       iproute2
Requires:       lastlog2
Requires:       libnss_usrfiles2
Requires:       pam
Requires:       pam-config
Requires:       procps
Requires:       rebootmgr
Requires:       rpm
Requires:       shadow
Requires:       systemd
Requires:       util-linux
Requires:       group(nobody)
Requires:       user(nobody)
####
Requires:       btrfsmaintenance
Requires:       busybox
Requires:       chrony
# curl indirectly needed by ignition via dracut's url-lib
Requires:       curl
# probably needed for fsck.fat on efi partitions
Requires:       /usr/bin/gzip
Requires:       MicroOS-release
Requires:       dosfstools
Requires:       glibc-locale-base
Suggests:       busybox-gzip
Requires:       iputils
Requires:       issue-generator
Requires:       (health-checker if grub2)
Requires:       (health-checker-plugins-MicroOS if health-checker)
%ifnarch %{arm}
Requires:       kdump
%endif
Requires:       less
Requires:       microos-tools
Requires:       openssh
Requires:       snapper
Requires:       vim-small
Requires:       wtmpdb
# people are addicted to sudo
Requires:       sudo
Requires:       systemd-presets-branding-MicroOS
Requires:       terminfo-base
Requires:       timezone
Conflicts:      gettext-runtime-mini
Conflicts:      krb5-mini
Requires:       yast2-logs

%description base
This is the openSUSE MicroOS runtime system. It contains only a minimal multiuser
booting system.

%package base-zypper
Summary:        openSUSE MicroOS using Zypper
Group:          Metapackages
Provides:       pattern() = microos_base_zypper
Provides:       pattern-category() = MicroOS
Provides:       pattern-icon() = pattern-kubic
Provides:       pattern-order() = 9011
Provides:       pattern-visible()
Requires:       transactional-update
Requires:       transactional-update-zypp-config
Requires:       zypper
Requires:       pattern() = microos_base
# zypper ps is useless in transactional mode. It also checks for
# /run/reboot-needed though which is created by transactional-update
Requires:       zypper-needs-restarting

%description base-zypper
This is the openSUSE MicroOS runtime system using the Zypper package manager.
It contains only a minimal multiuser booting system.

%package base-microdnf
Summary:        openSUSE MicroOS using Micro DNF
Group:          Metapackages
Provides:       pattern() = microos_base_microdnf
Provides:       pattern-category() = MicroOS
Provides:       pattern-icon() = pattern-kubic
Provides:       pattern-order() = 9012
Provides:       pattern-visible()
Requires:       libdnf-plugin-txnupd
Requires:       microdnf
Requires:       pattern() = microos_base
# We need repository configuration from somewhere, so
# make sure one gets installed
Requires:       (libdnf-repo-config-zypp or rpm-repos-openSUSE)
Suggests:       libdnf-repo-config-zypp

%description base-microdnf
This is the openSUSE MicroOS runtime system using the Micro DNF package manager.
It contains only a minimal multiuser booting system.

%package base-packagekit
Summary:        openSUSE MicroOS using PackageKit
Group:          Metapackages
Provides:       pattern() = microos_base_packagekit
Provides:       pattern-category() = MicroOS
Provides:       pattern-icon() = pattern-kubic
Provides:       pattern-order() = 9013
Provides:       pattern-visible()
Requires:       PackageKit
Requires:       PackageKit-branding-openSUSE
Requires:       libdnf-plugin-txnupd
Requires:       pattern() = microos_base
# We need repository configuration from somewhere, so
# make sure one gets installed
Requires:       (libdnf-repo-config-zypp or rpm-repos-openSUSE)
Suggests:       libdnf-repo-config-zypp

%description base-packagekit
This is the openSUSE MicroOS runtime system using the PackageKit service.
It contains only a minimal multiuser booting system.

%package defaults
Summary:        openSUSE MicroOS defaults
Group:          Metapackages
Provides:       pattern() = microos_defaults
Provides:       pattern-category() = MicroOS
Provides:       pattern-icon() = pattern-kubic
Provides:       pattern-order() = 9020
Requires:       audit
Requires:       systemd-coredump
Requires:       pattern() = microos_base

%description defaults
This provides default packages for openSUSE MicroOS which can be optionally
replaced by alternatives.

%package hardware
Summary:        Hardware Support
Group:          Metapackages
Provides:       pattern() = microos_hardware
Provides:       pattern-category() = MicroOS
Provides:       pattern-icon() = pattern-kubic
Provides:       pattern-order() = 9030
Provides:       pattern-visible()
Requires:       ethtool
%ifnarch s390x
Requires:       irqbalance
%endif
%ifarch %ix86 x86_64
Requires:       ucode-amd
Requires:       ucode-intel
%endif
Requires:       fcoe-utils
Requires:       hwinfo

%description hardware
Packages required to install openSUSE MicroOS on real hardware.

%package apparmor
Summary:        Apparmor Support
Group:          Metapackages
Provides:       pattern() = microos_apparmor
Provides:       pattern-category() = MicroOS
Provides:       pattern-icon() = pattern-apparmor
Provides:       pattern-order() = 9050
Provides:       pattern-visible()
Requires:       apparmor-parser
Requires:       apparmor-profiles

%description apparmor
Packages required to enable Apparmor on openSUSE MicroOS.

%package selinux
Summary:        SELinux Support
Group:          Metapackages
Provides:       pattern() = microos_selinux
Provides:       pattern-category() = MicroOS
Provides:       pattern-icon() = pattern-generic
Provides:       pattern-order() = 9055
Provides:       pattern-visible()
Requires:       container-selinux
Requires:       policycoreutils
Requires:       selinux-policy-targeted
Requires:       selinux-tools

%description selinux
This are packages which are required to enable SELinux on openSUSE MicroOS

%package cockpit
Summary:        Web based remote system managemet
Group:          Metapackages
Provides:       pattern() = microos_cockpit
Provides:       pattern-category() = MicroOS
Provides:       pattern-icon() = pattern-generic
Provides:       pattern-order() = 9060
Provides:       pattern-visible()
Requires:       cockpit-podman
Requires:       cockpit-system
# If PackageKit pattern is installed, pull in Cockpit's PackageKit module
Requires:       (cockpit-packagekit if patterns-microos-base-packagekit)

%description cockpit
Packages required to run the Cockpit system management service.
For the web service the cockpit-ws container is required.

%package sssd_ldap
Summary:        LDAP client
Group:          Metapackages
Provides:       pattern() = microos_sssd_ldap
Provides:       pattern-category() = MicroOS
Provides:       pattern-icon() = pattern-generic
Provides:       pattern-order() = 9070
Provides:       pattern-visible()
Requires:       sssd
Requires:       sssd-ldap

%description sssd_ldap
Packages required to enable LDAP client support via sssd on openSUSE MicroOS.

%package ima_evm
Summary:        IMA/EVM Support
Group:          Metapackages
Provides:       pattern() = microos_ima_evm
Provides:       pattern-category() = MicroOS
Provides:       pattern-icon() = pattern-basis-addon
Provides:       pattern-order() = 9080
Provides:       pattern-visible()
Requires:       attr
Requires:       dracut-ima
Requires:       ima-evm-utils
Requires:       keyutils

%description ima_evm
Packages required to enable IMA/EVM on openSUSE MicroOS.

%package ra_agent
Summary:        Remote Attestation (Agent) Support
Group:          Metapackages
Provides:       pattern() = microos_ra_agent
Provides:       pattern-category() = MicroOS
Provides:       pattern-icon() = pattern-basis-addon
Provides:       pattern-order() = 9085
Provides:       pattern-visible()
%ifarch %{ix86} ia64 x86_64 %{arm} aarch64
Requires:       dmidecode
%endif
Requires:       rust-keylime
Requires:       pattern() = microos_ima_evm

%description ra_agent
Packages required to enable remote attestation via the Rust Keylime
agent on openSUSE MicroOS.

%package ra_verifier
Summary:        Remote Attestation (Verifier) Support
Group:          Metapackages
Provides:       pattern() = microos_ra_verifier
Provides:       pattern-category() = MicroOS
Provides:       pattern-icon() = pattern-basis-addon
Provides:       pattern-order() = 9086
Provides:       pattern-visible()
Requires:       keylime-firewalld
Requires:       keylime-registrar
Requires:       keylime-tenant
Requires:       keylime-verifier

%description ra_verifier
Packages required to enable remote attestation via Keylime verifier on
openSUSE MicroOS.

%package cloud
Summary:        Support for Cloud
Group:          Metapackages
Provides:       pattern() = microos_cloud
Provides:       pattern-category() = MicroOS
Provides:       pattern-icon() = pattern-generic
Provides:       pattern-order() = 9090
Provides:       pattern-visible()
Requires:       cloud-init
Requires:       cloud-init-config-MicroOS

%description cloud
Packages required to enable openSUSE MicroOS in the Cloud.

%package desktop-common
Summary:        Common packages for Desktops on MicroOS
Group:          Metapackages
Provides:       pattern() = microos_desktop_common
Provides:       pattern-category() = MicroOS
Provides:       pattern-icon() = pattern-x11
Provides:       pattern-order() = 9100
Requires:       pattern() = x11

# PipeWire is the default sound server
Requires:       gstreamer-plugin-pipewire
Requires:       pipewire-alsa
Requires:       pipewire-pulseaudio
# This approach unfortunately breaks Tumbleweed (boo#1194264)
#Obsoletes:      alsa-plugins-pulse < 1.3
#Obsoletes:      pulseaudio < 14.3
#Obsoletes:      pulseaudio-module-bluetooth < 14.3
#Obsoletes:      pulseaudio-module-gsettings < 14.3
#Obsoletes:      pulseaudio-module-x11 < 14.3
#Obsoletes:      pulseaudio-module-zeroconf < 14.3

# Allow users to print (and add some common printer drivers)
Requires:       OpenPrintingPPDs
Requires:       bluez-cups
Requires:       cups
Requires:       cups-filters
Requires:       cups-pk-helper
Requires:       ghostscript
Requires:       hplip-hpijs
Requires:       system-config-printer-common
Requires:       system-config-printer-dbus-service
Requires:       udev-configure-printer

# Add thunderbolt device management (boo#1208150)
Requires:       bolt

# Common tools
Requires:       bash-completion
Requires:       bluez-firmware
Requires:       glibc-locale
Requires:       hicolor-icon-theme-branding-openSUSE
Requires:       policycoreutils-python-utils
Requires:       polkit-default-privs
Requires:       systemd-icon-branding-openSUSE
Requires:       udisks2
Requires:       unzip
Requires:       upower
Requires:       wget
Requires:       xdg-utils

# Support ntfs drives
Requires:       ntfs-3g
Requires:       ntfsprogs

# More "comfortable" base package versions
Requires:       gzip
Requires:       hostname

%if 0%{is_opensuse}
Requires:       avahi
%endif

# Desktop notifications about transactional update succeeding/failing
# for the masses
Requires:       transactional-update-notifier

# Needed by both GNOME and KDE for theming of GTK-based flatpak apps properly
Requires:       xdg-desktop-portal-gtk

# Needed to ensure MicroOS Desktop systems are be able to handle varied hardware out
# of the box, and not only during the system installation.
Requires:       kernel-firmware-all
Requires:       sof-firmware

%description desktop-common
Packages required for openSUSE MicroOS Desktops.

%package desktop-gnome
Summary:        MicroOS GNOME Desktop
Group:          Metapackages
Provides:       pattern() = microos_gnome_desktop
Provides:       pattern-category() = MicroOS
Provides:       pattern-icon() = pattern-gnome
Provides:       pattern-order() = 9100
Provides:       pattern-visible()
Requires:       gdm-branding-MicroOS
Requires:       pattern() = gnome_basic
Requires:       pattern() = microos_base_zypper
Requires:       pattern() = microos_desktop_common
# gnome-initial-setup requirements
Requires:       gnome-initial-setup
Requires:       gjs
Requires:       gnome-menus-branding-openSUSE
Requires:       system-group-wheel
# from data/COMMON-DESKTOP
Requires:       desktop-data
Requires:       desktop-file-utils
#
# Now the real packages
#
# #332596
Requires:       gnome-keyring-pam
# implied by gnome-keyring-pam
#Requires:     gnome-keyring
Requires:       gnome-disk-utility
# implied by gdm
#Requires: gnome-shell
#Requires: gnome-settings-daemon
# implied by gnome-shell
#Requires:       gnome-control-center
#
# Default sessions:
# - We also explicitly put the packages required by those sessions, in case
#   gnome-session-*-session is not installable, to make sure the livecd is
#   somehow a bit usable
#
Requires:       gnome-session-default-session
# ensure we have wayland session available (and used by default)
Requires:       gnome-session-wayland
# boo#1090117
Requires:       flatpak
Requires:       gnome-branding-MicroOS
Requires:       gnome-color-manager
#Requires:       gnome-packagekit
Requires:       gnome-shell-classic
Requires:       gnome-software
Requires:       gnome-system-monitor
Requires:       gnome-terminal
Requires:       gnome-tweak-tool
Requires:       gnome-user-docs
# bnc#879466
Requires:       gpgme
# for online accounts and calendar integration
Requires:       gnome-bluetooth
# for display color profile support
Requires:       gnome-control-center-color
# needed to ensure bluetooth is enabled at startup (glgo#GNOME/gnome-bluetooth#110)
Requires:       bluez-auto-enable-devices
Requires:       gnome-control-center-goa
Requires:       gnome-online-accounts
Requires:       gnome-shell-calendar
# For seeing thumbnails in Nautilus
Requires:       gdk-pixbuf-thumbnailer
Requires:       gsf-office-thumbnailer
Requires:       rsvg-thumbnailer
# So that GNOME shell extensions can be installed
Requires:       chrome-gnome-shell
# we need something for xdg-su
Requires:       gnome-shell-search-provider-nautilus
Requires:       libgnomesu
Requires:       nautilus
Requires:       nautilus-extension-terminal
Requires:       nautilus-share
# For encrypting and decrypting files to work in Nautilus
Requires:       nautilus-extension-seahorse
Requires:       seahorse-daemon
# So Trash and mounting USB sticks work in Nautilus
Requires:       gvfs-backends
Requires:       gvfs-backend-afc
Requires:       gvfs-backend-goa
Requires:       gvfs-fuse
# We need the icons to work
Requires:       adwaita-icon-theme
# We need this for accessability and the lack of it causes big performance issues (boo#1204564)
Requires:       at-spi2-core
# Some fonts
Requires:       adobe-sourcecodepro-fonts
Requires:       adobe-sourcesanspro-fonts
Requires:       adobe-sourceserifpro-fonts
Requires:       dejavu-fonts
Requires:       ghostscript-fonts-other
Requires:       ghostscript-fonts-std
Requires:       google-carlito-fonts
Requires:       google-droid-fonts
Requires:       google-opensans-fonts
Requires:       google-roboto-fonts
Requires:       noto-coloremoji-fonts
Requires:       noto-emoji-fonts
Requires:       noto-sans-fonts
# So that GNOME keyring works
Requires:       gcr-ssh-askpass
Requires:       gcr3-ssh-askpass
# So that GNOME prompt for ssh password works
Requires:       openssh-askpass-gnome
# So that GNOME pinentry works
Requires:       pinentry-gnome3
Requires:       gvfs-backend-samba
Requires:       samba
# So that GNOME builtin screen recorder works
Requires:       gstreamer-plugins-bad
Requires:       gstreamer-plugins-good
# #509829
Requires:       xdg-user-dirs-gtk
Requires:       yelp
# Polkit integration with GNOME
Requires:       polkit-gnome
# https://build.opensuse.org/request/show/921373
Requires:       xdg-desktop-portal-gnome
# ensure laptop power support is there
Requires:       (power-profiles-daemon or tlp)
Suggests:       power-profiles-daemon

# Add steam-devices for controller and other gaming device support.
Requires:       steam-devices

#
# Low-level parts that we need
#
%if 0%{is_opensuse}
# bnc#430161
Requires:       NetworkManager-openconnect-gnome
Requires:       NetworkManager-openvpn-gnome
Requires:       canberra-gtk-play
#
# Branding
#
# #591535
Requires:       gtk2-branding-openSUSE
Requires:       gtk3-branding-openSUSE
Requires:       gtk4-branding-openSUSE
%endif

%description desktop-gnome
Packages required for the openSUSE MicroOS Desktop with GNOME.

%package desktop-kde
Summary:        MicroOS KDE Plasma Desktop
Group:          Metapackages
Provides:       pattern() = microos_kde_desktop
Provides:       pattern-category() = MicroOS
Provides:       pattern-icon() = pattern-kde
Provides:       pattern-order() = 9101
Provides:       pattern-visible()
Requires:       pattern() = kde_plasma
Requires:       pattern() = microos_desktop_common
# Pull in transactional-update
Requires:       pattern() = microos_base_zypper

# Pull in plasma-branding-MicroOS for firstboot setup
Requires:       plasma-branding-MicroOS

# Some basic system tools
Requires:       kate
Requires:       konsole
# Add KDE Partition Manager to install pattern (boo#1212925)
Requires:       partitionmanager

# Add ksshaskpass5 (boo#1215407)
Requires:       ksshaskpass5

#KAccounts to be installed by default (boo#1216397)
Requires:       kaccounts-integration
Requires:       kaccounts-providers
Requires:       kio-gdrive

# Recommended by kde_plasma
Requires:       bluedevil5
Requires:       breeze5-wallpapers
Requires:       dolphin
Requires:       kde-print-manager
Requires:       kgamma5
Requires:       kwrited5
Requires:       phonon4qt5-backend-vlc
Requires:       plasma-nm5

# Manually pull in baloo5-file to better support desktop search functions/desktop integration
Requires:       baloo5-file

# For NetworkManager support of openVPN Connections
Requires:       NetworkManager-openvpn
Requires:       openvpn-auth-pam-plugin
Requires:       plasma-nm5-openconnect
Requires:       plasma-nm5-openvpn

Requires:       kio-extras5
Requires:       kwalletmanager5
Requires:       pinentry-qt5
Requires:       plasma5-addons
Requires:       plasma5-pa
Requires:       plasma5-session-wayland
Requires:       sddm

# Additional Fonts to cover Unicode Symbols not provided by the fonts pulled in by kde_plasma Pattern
Requires:       noto-sans-math-fonts
Requires:       google-noto-sans-cjk-fonts

# Recommends and Supplements won't work, so pull in manually
Requires:       discover-backend-flatpak
Requires:       discover-backend-fwupd
#Requires:       discover-backend-packagekit
Requires:       kde-gtk-config5
Requires:       kde-gtk-config5-gtk3
Requires:       plasma-browser-integration
Requires:       plasma5-defaults-openSUSE
Requires:       purpose
Requires:       qqc2-desktop-style
Requires:       sddm-theme-openSUSE
Requires:       xdg-desktop-portal-kde

# Recommended by powerdevil5, but allow tlp as alternative
Requires:       (power-profiles-daemon or tlp)
Suggests:       power-profiles-daemon

# Doesn't depend on PackageKit, but also works for other backends
Requires:       discover-notifier

# Spectacle to be able to take screenshots out of the box
Requires:       spectacle

# Default Plasma app to quickly use emojis
Requires:       plasma5-desktop-emojier
Requires:       google-noto-coloremoji-fonts

# Breeze GTK2, GTK3 and GTK4
Requires:       (gtk4-metatheme-breeze if gtk4)
Requires:       (gtk2-metatheme-breeze if gtk2)
Requires:       (gtk3-metatheme-breeze if gtk3)

# Default Plasma/Oxygen sounds for applications
Requires:       oxygen5-sounds

# Plasma system monitor
Requires:       plasma5-systemmonitor

# For seeing thumbnails in Dolphin
Requires:       libqt5-qtimageformats
Requires:       ffmpegthumbs
Requires:       kdegraphics-thumbnailers

# For being able to change SDDM settings
Requires:       kcm_sddm

# Add for mounting network shares in userspace (boo#1210125)
Requires:       kio-fuse
Requires:       kdenetwork-filesharing

# Add kcm_flatpak for managing flatpak permissions (boo#1208256)
Requires:       kcm_flatpak

# Add steam-devices for controller support
Requires:       steam-devices

%description desktop-kde
Packages required for the openSUSE MicroOS with KDE Plasma

%package onlyDVD
Summary:        Packages only for the DVD of openSUSE MicroOS
Group:          Metapackages
Provides:       pattern-category() = MicroOS
Requires:       apparmor-utils
Requires:       bcache-tools
Requires:       crda
Requires:       cryptsetup
Requires:       firewalld
Requires:       iscsiuio
#extra items for DVD, not every install
Requires:       ModemManager
Requires:       NetworkManager-wwan
Requires:       lvm2
Requires:       multipath-tools
Requires:       nvme-cli
Requires:       open-iscsi
%ifarch %ix86 x86_64 aarch64
Requires:       hyper-v
Requires:       open-vm-tools
%endif
Requires:       pam_pwquality
Requires:       policycoreutils-python-utils
Requires:       qemu-guest-agent
%ifarch %{ix86} x86_64 aarch64
Requires:       sdbootutil
Requires:       sdbootutil-rpm-scriptlets
Requires:       sdbootutil-snapper
Requires:       systemd-boot
%endif
Requires:       spice-vdagent
Requires:       tftpboot-installation-openSUSE-MicroOS-%{_target_cpu}
Requires:       wpa_supplicant
Requires:       xfsprogs
Provides:       pattern() = microos_onlyDVD
Provides:       pattern-icon() = pattern-generic
Provides:       pattern-order() = 9900
Requires:       pattern() = microos_apparmor
Requires:       pattern() = microos_cloud
Requires:       pattern() = microos_hardware
Requires:       pattern() = microos_ima_evm
Requires:       pattern() = microos_ra_agent
Requires:       pattern() = microos_sssd_ldap

%description onlyDVD
Additional packages on a openSUSE MicroOS DVD.

%package alt_onlyDVD
Summary:        Alternative Packages only for the DVD of openSUSE MicroOS
Group:          Metapackages
Provides:       pattern-category() = MicroOS
%ifnarch s390 s390x
Requires:       kernel-default-base
%endif
Provides:       pattern() = microos_alt_onlyDVD
Provides:       pattern-icon() = pattern-generic
Provides:       pattern-order() = 9901
Requires:       pattern() = bootloader
Requires:       pattern() = microos_apparmor
Requires:       pattern() = microos_cloud
Requires:       pattern() = microos_cockpit
Requires:       pattern() = microos_ima_evm
Requires:       pattern() = microos_ra_verifier
Requires:       pattern() = microos_selinux
Requires:       pattern() = microos_sssd_ldap

%description alt_onlyDVD
Alternative additional packages on a openSUSE MicroOS DVD.

%prep
# empty on purpose

%build
# empty on purpose

%install
mkdir -p %{buildroot}%{_docdir}/patterns-microos/
PATTERNS='
    basesystem base base_zypper base_microdnf base_packagekit defaults hardware
    sssd_ldap ima_evm ra_agent ra_verifier apparmor selinux cockpit cloud
    desktop-common desktop-gnome desktop-kde onlyDVD alt_onlyDVD
'
for i in $PATTERNS; do
    echo "This file marks the pattern $i to be installed." \
        > %{buildroot}%{_docdir}/patterns-microos/${i}.txt
done

%files basesystem
%dir %{_docdir}/patterns-microos
%{_docdir}/patterns-microos/basesystem.txt

%files base
%dir %{_docdir}/patterns-microos
%{_docdir}/patterns-microos/base.txt

%files base-zypper
%dir %{_docdir}/patterns-microos
%{_docdir}/patterns-microos/base_zypper.txt

%files base-microdnf
%dir %{_docdir}/patterns-microos
%{_docdir}/patterns-microos/base_microdnf.txt

%files base-packagekit
%dir %{_docdir}/patterns-microos
%{_docdir}/patterns-microos/base_packagekit.txt

%files defaults
%dir %{_docdir}/patterns-microos
%{_docdir}/patterns-microos/defaults.txt

%files hardware
%dir %{_docdir}/patterns-microos
%{_docdir}/patterns-microos/hardware.txt

%files sssd_ldap
%dir %{_docdir}/patterns-microos
%{_docdir}/patterns-microos/sssd_ldap.txt

%files ima_evm
%dir %{_docdir}/patterns-microos
%{_docdir}/patterns-microos/ima_evm.txt

%files ra_agent
%dir %{_docdir}/patterns-microos
%{_docdir}/patterns-microos/ra_agent.txt

%files ra_verifier
%dir %{_docdir}/patterns-microos
%{_docdir}/patterns-microos/ra_verifier.txt

%files apparmor
%dir %{_docdir}/patterns-microos
%{_docdir}/patterns-microos/apparmor.txt

%files selinux
%dir %{_docdir}/patterns-microos
%{_docdir}/patterns-microos/selinux.txt

%files cockpit
%dir %{_docdir}/patterns-microos
%{_docdir}/patterns-microos/cockpit.txt

%files cloud
%dir %{_docdir}/patterns-microos
%{_docdir}/patterns-microos/cloud.txt

%files desktop-common
%dir %{_docdir}/patterns-microos
%{_docdir}/patterns-microos/desktop-common.txt

%files desktop-gnome
%dir %{_docdir}/patterns-microos
%{_docdir}/patterns-microos/desktop-gnome.txt

%files desktop-kde
%dir %{_docdir}/patterns-microos
%{_docdir}/patterns-microos/desktop-kde.txt

%files onlyDVD
%dir %{_docdir}/patterns-microos
%{_docdir}/patterns-microos/onlyDVD.txt

%files alt_onlyDVD
%dir %{_docdir}/patterns-microos
%{_docdir}/patterns-microos/alt_onlyDVD.txt

%changelog
* Tue Jan 30 2024 Shawn Dunn <sfalken@opensuse.org>
- Add "Requires: steam-devices" for both Gnome and KDE
  * This package is just a small set of udev rules for controller
  support, and is one of the more common reasons for end users to
  need to interact with transactional-update, no good reason to not
  include it in the desktop patterns
* Thu Jan 18 2024 Fabian Vogt <fvogt@suse.com>
- Switch from phonon4qt5-backend-gstreamer to phonon4qt5-backend-vlc
  as recommended by upstream
* Wed Dec 13 2023 Ludwig Nussel <lnussel@suse.com>
- Require build-key instead of openSUSE-build-key. This allows for
  forked projects to include their own keys.
- remove Obsoletes: suse-build-key. Doesn't seem to be the job of a
  pattern.
* Wed Nov  8 2023 Luca Di Maio <luca.dimaio1@gmail.com>
- Remove grub as it breaks systemd-boot
- grub2-snapper-plugin now checks for grub instead of snapper, we reasonably can
  assume that a microos system has snapper installed anyway
* Sat Nov  4 2023 Luca Di Maio <luca.dimaio1@gmail.com>
- Add NetworkManager-bluetooth for bluetooth tethering support
- Add gnome-control-center-color for display color profile support
* Sat Nov  4 2023 Luca Di Maio <luca.dimaio1@gmail.com>
- Add back grub2-snapper-plugin in order to have back menu for older snapshots
* Fri Oct 20 2023 Natasha Ament <stacheldrahtje@gmail.com>
  KAccounts to be installed by default for KDE Plasma option (boo#1216397)
- Requires:   kaccounts-integration
- Requires:   kaccounts-providers
- Requires:   kio-gdrive
* Thu Oct 12 2023 Dominique Leuenberger <dimstar@opensuse.org>
- Also only require sdboot* on architectures where systemd-boot
  exists.
* Wed Oct 11 2023 Dominique Leuenberger <dimstar@opensuse.org>
- Only require systemd-boot on architectures where it exists
  (%%{ix86} x86_64 aarch64).
* Wed Oct 11 2023 Fabian Vogt <fvogt@suse.com>
- Exclude kernel-default-base on s390(x), it doesn't exist there
* Fri Oct  6 2023 Thorsten Kukuk <kukuk@suse.com>
- Add RPMs for systemd-boot to DVD
* Thu Oct  5 2023 Fabian Vogt <fvogt@suse.com>
- Only pull in health-checker if grub2 is installed, in other cases
  it won't really work: With sd-boot, the default btrfs subvol is not
  used, so rollbacks have no effect.
* Sun Sep 17 2023 Shawn Dunn <sfalken@opensuse.org>
- Add ksshaskpass5 (boo#1215407)
* Wed Sep 13 2023 Stefan Schubert <schubi@suse.com>
- Install grub2-branding-openSUSE if grub2 will be used.
  (Added in base pattern).
* Sun Sep 10 2023 Thorsten Kukuk <kukuk@suse.com>
- Add coreutils-systemd, coreutils got splitted in two RPMs
* Wed Aug  9 2023 Fabian Vogt <fvogt@suse.com>
- Add ucode-{amd,intel} to the hardware pattern
* Mon Jul  3 2023 Shawn Dunn <sfalken@opensuse.org>
- Add KDE partition manager to the default plasma install (boo#1212925)
* Mon Jun 19 2023 Dominique Leuenberger <dimstar@opensuse.org>
- Add bootlader dependency to the onlyDVD pattern: we still should
  ensure this ends up at least on the DVD.
* Wed May 24 2023 Stefan Schubert <schubi@suse.com>
- Removed requirement of bootloader in order to use systemd-boot
  only. Grub is still available but there is no hard requirement
  anymore.
* Tue May  9 2023 Thorsten Kukuk <kukuk@suse.com>
- Use wtmpdb as Y2038 safe wtmp replacement
* Thu May  4 2023 Richard Brown <rbrown@suse.com>
- Add Requires for gvfs-backend-goa and gvfs-backend-afc to better
  support filesystems configured by gnome-online-accounts and Apple
  mobile devices
* Thu Apr 20 2023 Richard Brown <rbrown@suse.com>
- Relocate the below change to kernel-firmware-all and sof-firmware
  from base pattern to desktop-common - the requirement is for
  very broad hardware support Desktops, not ever MicroOS install
* Wed Apr 19 2023 Luciano Santos <luc14n0@opensuse.org>
- Add kernel-firmware-all and sof-firmware to the base pattern.
  This should ensure any MicroOS system can handle the various
  kinds/vendors of hardware out of the box, since those systems
  don't use package recommendation/supplementation (boo#1184767,
  boo#1210483).
- Add missing gtk4-branding-openSUSE requirement (GTK2 and GTK3 are
  already being required).
- Drop duplicated NetworkManager requirement from GNOME pattern.
  This is part of the base pattern which get's pulled in by any
  MicrOS system.
- Move xdg-desktop-portal-gtk to the desktop common pattern. Both
  GNOME and KDE need it for proper theming of GTK-based flatpak
  apps.
* Mon Apr 10 2023 Shawn Dunn <sfalken@opensuse.org>
- Add discover-backend-fwupd for automated firmware updates on
  plasma
* Thu Apr  6 2023 Thorsten Kukuk <kukuk@suse.com>
- Use lastlog2 as Y2038 safe lastlog replacement
* Wed Apr  5 2023 Shawn Dunn <sfalken@opensuse.org>
- Add Requires kio-fuse and kdenetwork-filesharing to kde pattern
  (boo#1210125)
* Tue Apr  4 2023 Ludwig Nussel <lnussel@suse.de>
- Add systemd-coredump to defaults (boo#1091684)
- remove systemd-logger requirement from defaults. It got merged into the main
  package meanwhile.
* Mon Mar 27 2023 Enrico Belleri <idesmi@protonmail.com>
- Change xdg-desktop-portal-gnome to xdg-desktop-portal-gtk: it's meant for GNOME DE
- Add Requires gtk4-metatheme-breeze
- Clean specfile
* Mon Mar 13 2023 Shawn Dunn <sfalken@opensuse.org>
- Add openconnect VPN support to both Gnome and Plasma
  (boo#1209171)
- Add NetworkManager-openconnect-gnome
- Add plasma-nm5-openconnect
* Wed Feb 15 2023 Shawn Dunn <sfalken@opensuse.org>
- Add kcm_flatpak to plasma default install (boo#1208256)
* Sat Feb 11 2023 Richard Brown <rbrown@suse.com>
- Add thunderbolt device management to desktop-common (boo#1208150)
* Thu Feb  9 2023 Fabian Vogt <fvogt@suse.com>
- Comment out gtk4-metatheme-breeze until Plasma 5.27
* Thu Feb  9 2023 Denys Madureira <denysmb@zoho.com>
- Add the folowing packages for Plasma Desktop pattern
- Add spectacle
- Add plasma5-desktop-emojier and google-noto-coloremoji-fonts
- Add gtk2-metatheme-breeze, gtk3-metatheme-breeze and gtk4-metatheme-breeze
- Add oxygen5-sounds
- Add plasma5-systemmonitor
- Add libqt5-qtimageformats, kdegraphics-thumbnailers and ffmpegthumbs (for thumbnails)
- Add kcm_sddm
* Wed Feb  8 2023 Richard Brown <rbrown@suse.com>
- Remove gnome-usage (obsolete upstream), restore gnome-system-monitor for
  GNOME Desktop (boo#1205108)
* Wed Feb  1 2023 Shawn Dunn <sfalken@opensuse.org>
- Add baloo5-file to kde pattern, missed as a recommended in
  pattern, required for a number of desktop search functions
* Wed Jan 11 2023 Luciano Santos <luc14n0@opensuse.org>
- Add transactional-update-notifier to the microos_desktop_common
  Pattern. This is a long waited change that will provide Desktop
  notifications about transactional updates succeeding/failing for
  MicroOS Desktop users.
- Improve readability of FOR loop shell construct, in the install
  directive, by assigning all the Patterns iterated by FOR to the
  PATTERNS variable (for i in $PATTERNS) instead of passing them
  directly (for i in pattern1 pattern2 pattern3 ...).
- Rename patterns-microos-rpmlintrc to patterns-microos.rpmlintrc.
  While the former is obviously supported, the latter is both
  preferred and recommended by upstream.
* Fri Nov 25 2022 Richard Brown <rbrown@suse.com>
- Remove redundant gnome-system-monitor (boo#1205108)
* Fri Nov 18 2022 Shawn Dunn <sfalken@cloverleaf-linux.org>
- Add fonts to KDE pattern, so common unicode characters are
  displayed on default install (boo#1205546)
- Add noto-sans-math-fonts
- google-noto-sans-cjk-fonts
* Wed Nov 16 2022 Shawn Dunn <sfalken@cloverleaf-linux.org>
- Add Packages to KDE pattern, to allow for openvpn connections
  through NetworkManager on fresh installs. (boo#1205501)
- Add NetworkManager-openvpn
- Add plasma-nm5-openvpn
- Add openvpn-auth-pam-plugin
* Wed Nov 16 2022 Luca Di Maio <luca.dimaio1@gmail.com>
- Add gstreamer-plusing-bad and gstreamer-plugins-good to ensure GNOME's builtin
  screen recorder works correctly.
* Mon Nov 14 2022 Luca Di Maio <luca.dimaio1@gmail.com>
- Add gvfs-fuse
- Add gvfs-backend-samba
- Add ntfs support (useful for external drives and such)
- Add openssh-askpass-gnome and pinentry-gnome3 to have working prompts on GNOME
- Add polkit-gnome for polkit integration
* Sat Nov 12 2022 Shawn Dunn <sfalken@cloverleaf-linux.org>
- Add xdg-desktop-portal-gnome to -kde install pattern, to correct
  for mangled fonts, and theming, while using GTK apps on MicroOS
  KDE (boo#1205631)
* Wed Nov  2 2022 Richard Brown <rbrown@suse.com>
- cups-pk-helper shouldn't be linked to PackageKit, as "pk" stands
  for PolicyKit in this case (boo#1204949)
* Thu Oct 27 2022 Richard Brown <rbrown@suse.com>
- Add gcr3-ssh-askpass as it's also needed with latest GNOME
* Fri Oct 21 2022 Richard Brown <rbrown@suse.com>
- Require at-spi2-core else risk major performance issues (boo#1204564)
* Wed Oct 19 2022 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Do not require kdump on 32-bit arm - boo#1203888
* Mon Oct 17 2022 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Replace tftpboot-installation-openSUSE-MicroOS-%%{_arch}
  with tftpboot-installation-openSUSE-MicroOS-%%{_target_cpu}
  to match what installation-images:MicroOS produces
* Tue Oct  4 2022 Fabian Vogt <fabian@ritter-vogt.de>
- Remove steam-devices again, it's only in the Non-OSS repo
* Fri Sep 30 2022 Fabian Vogt <fvogt@suse.com>
- Pull in power-profiles-daemon in the Plasma pattern as well
- Allow tlp as alternative to power-profiles-daemon (boo#1198549)
* Fri Sep 30 2022 Dirk Müller <dmueller@suse.com>
- enable build for RISCV64
- spec cleanups
* Tue Sep 27 2022 Alberto Planas Dominguez <aplanas@suse.com>
- Add keylime-tenant requirement for the ra_verifier role (new subpackage)
* Thu Sep 15 2022 Shawn Dunn <sfalken@cloverleaf-linux.org>
- Add general desktop Requires: steam-devices.  This package is
  highly unlikely to ever be provided through flatpak, and causes
  close to zero impact on the base system, as it quite literally
  contains 1 file with six udev rules. Provides for a seamless out-
  of-box experience for anybody using the steam flatpak, without it,
  any users running steam will need to install manually via t-u.
* Mon Aug  8 2022 Fabian Vogt <fvogt@suse.com>
- Have onlyDVD require ra_agent and alt_onlyDVD ra_verifier to allow
  conflicts between them
* Mon Jul 25 2022 Syds Bearda <opensuse@syds.eu>
- Changing KDE back to transactional-update as well.
- removed gnome-packagekit and discover-backend-packagekit
* Thu Jul 21 2022 Shawn Dunn <sfalken@cloverleaf-linux.org>
- Add plasma-branding-MicroOS to the default install for MicroOS-KDE
* Thu Jun 30 2022 Richard Brown <rbrown@suse.com>
- Use gnome-initial-setup for configuring user on firstboot of MicroOS Desktop
* Tue Jun 21 2022 Fabian Vogt <fvogt@suse.com>
- Add firewalld to the DVD pattern as YaST can be used to configure it
  during installation (boo#1200741)
* Mon Jun 20 2022 Thorsten Kukuk <kukuk@suse.com>
- Remove tallow, doesn't work with firewalld using nft anymore
* Tue Jun 14 2022 Alberto Planas Dominguez <aplanas@suse.com>
- Make the Rust Keylime agent the default one for ra_agent
* Mon Jun 13 2022 Alberto Planas Dominguez <aplanas@suse.com>
- Drop cfssl requirement for ra_verifier, as openssl can now do
  revocation.
* Mon May 30 2022 Frederic Crozat <fcrozat@suse.com>
- Ensure power-profiles-daemon is installed by Desktop GNOME
  pattern.
* Thu May 19 2022 Syds Bearda <opensuse@syds.eu>
- NetworkManager 1.38.0 is split into different packages and doesn't
  require the wifi and wwan module, therefore added here as required.
  added NetworkManager-wifi to common and NetworkManager-wwan to DVD
* Wed Apr 13 2022 Richard Brown <rbrown@suse.com>
- Revert "Remove requirement of pattern-bootloader". Containers
  should not be using pattern-microos-base. MicroOS needs pattern
  for having a branded bootloader
* Tue Apr 12 2022 Frederic Crozat <fcrozat@suse.com>
- Ensure bluez-auto-enable-devices is required for GNOME desktop
  (glgo#GNOME/gnome-bluetooth#110).
* Fri Feb  4 2022 Richard Brown <rbrown@suse.com>
- Do not include wicked in base pattern, NetworkManager instead
* Thu Feb  3 2022 Fabian Vogt <fvogt@suse.com>
- Disable pulseaudio obsoletes. Most (if not all) systems already
  upgraded to pipewire, so this avoids the issues this causes on TW
  (boo#1194264)
* Tue Feb  1 2022 Dario Faggioli <dfaggioli@suse.com>
- Remove redundant pipewire dependencies as they are all brough
  in by `pipewire`, which should be brought in by `pipewire-pulseaudio`
* Wed Jan 12 2022 Syds Bearda <opensuse@syds.eu>
- Added kde-gtk-config5-gtk3 to the KDE pattern, so that System
  Settings can also change GTK theming, which is generally used for
  flatpaks.
* Thu Dec  2 2021 Alberto Planas Dominguez <aplanas@suse.com>
- Remove requirement of pattern-bootloader. This pattern is currenly
  present in the Kiwi appliance, and the presence here can complicate
  the creation of containers that use pattern-microos-base.
* Tue Nov  2 2021 Richard Brown <rbrown@suse.com>
- Add policycoreutils-python-utils to desktop-common
  While it's too heavyweight for regular MicroOS patterns, on an
  interactively used desktop system its nice to have the tools to
  debug when selinux goes wrong.
* Wed Oct 27 2021 Alberto Planas Dominguez <aplanas@suse.com>
- Install dmidecode only on archs where it is available
* Fri Oct 22 2021 Richard Brown <rbrown@suse.com>
- Add NetworkManager-openvpn-gnome to gnome pattern
* Thu Oct  7 2021 Teoh Han Hui <teohhanhui@gmail.com>
- Add xdg-desktop-portal-gnome to gnome pattern
* Wed Sep 29 2021 Bjørn Lie <bjorn.lie@gmail.com>
- Drop gnome-power-manager Requires: Package is dormant upstream
  and on it's way to be replaced by new features inside of
  gnome-control-center.
* Mon Sep  6 2021 Thorsten Kukuk <kukuk@suse.com>
- Add ethtool to hardware pattern [jsc#PM-2983]
* Mon Sep  6 2021 Thorsten Kukuk <kukuk@suse.com>
- Remove haveged (obsolete with recent kernels) [bsc#1190024]
* Wed Aug 11 2021 Teoh Han Hui <teohhanhui@gmail.com>
- Switch from PulseAudio to PipeWire
* Thu Jul  8 2021 Alberto Planas Dominguez <aplanas@suse.com>
- Requires CFSSL for the verifier pattern
* Mon Jun 21 2021 Alberto Planas Dominguez <aplanas@suse.com>
- Add remote attestation patterns
- Consolidate pattern-icon to pattern-basis-addon together with ima_evm
* Wed May 19 2021 Dario Faggioli <dfaggioli@suse.com>
- Drop partitionmanager due to bsc#1178848.
  We'll revisit when that is fixed.
* Fri May 14 2021 Dario Faggioli <dfaggioli@suse.com>
- make cups-pk-helper conditional to PackageKit
* Fri May 14 2021 Dario Faggioli <dfaggioli@suse.com>
- add qemu-guest-agent to the DVD, to improve experience in case we
  install in a VM
- add some cups and printing related packages so that a new printer
  can actually be succesfully added (tested with GNOME only)
- add some disk handling GUI tools (for partitioning USB keys, ext.
  disks, etc) for both GNOME and KDE
* Wed May 12 2021 Neal Gompa <ngompa13@gmail.com>
- Conditionally install cockpit-packagekit in the Cockpit pattern
  if the PackageKit pattern is installed to allow system updates
  through Cockpit on package managed MicroOS systems.
- Fix previous changelog entry to be formatted correctly
* Thu May  6 2021 Syds Bearda <opensuse@syds.eu>
- Added the following to the pattern:
  + glibc-locale to the desktop common pattern as it's necessary to
    choose a different language in Gnome settings
  + ModemManager to the DVD only pattern. So I can choose it in the
    software section during install. For times there is no WiFi or
    Ethernet, but a WWAN modem is available to the system.
* Thu Apr 22 2021 Fabian Vogt <fvogt@suse.com>
- Suggest libdnf-repo-config-zypp explicitly
- Fix dependency on systemd-icon-branding-openSUSE
- Use only kernel-firmware-all instead of kernel-firmware to avoid
  duplicate firmware on the DVD
- spice-vdagent is available on all archs
- hyper-v and open-vm-tools are available on AArch64 as well
* Fri Apr 16 2021 Dario Faggioli <dfaggioli@suse.com>
- A fresh install does not have xdg-open & friends. Fix by adding xdg-utils
- while there, fix the comment, as they're common tools, but not
  necessarily useful only "during initial setup"
* Fri Apr 16 2021 Syds Bearda <opensuse@syds.eu>
- Add packages to the desktop commons pattern:
  systemd-icons-branding-openSUSE (to list the MicroOS logo on the
  Gnome Settings About page)
* Thu Apr 15 2021 Dario Faggioli <dfaggioli@suse.com>
- Add packages to the DVD:
  - instead of adding firmware-all, add specific firmware packages for
  common hardware (or at least, for hardware for which we have bugs
  open, see bsc#1184767 and bsc#1184403)
* Sat Apr 10 2021 Dario Faggioli <dfaggioli@suse.com>
- Add some packages in the DVD:
  - Spice guest driver so graphics works properly out of the box,
  when installing in VMs (mostly for desktops)
  - firmwares so that (wireless mostly, bot also wired) networking
  works in the installer and on the installed system
* Mon Mar 22 2021 Richard Brown <rbrown@suse.com>
- Remove gnome-calculator and add gnome-branding-MicroOS to MicroOS
  GNOME Desktop
* Mon Mar 22 2021 Richard Brown <rbrown@suse.com>
- Add gnome-shell-search-provider-nautilus and gnome-color-manager
  to MicroOS GNOME Desktop
- gnome-color-manager needed for Night Light
* Wed Mar  3 2021 Thorsten Kukuk <kukuk@suse.com>
- Use busybox hostname and gzip for MicroOS except for the Desktop
- Require util-linux instead of "login" alias
- Remove supportutils, we didn't use it and it pulls in more than
  we want
* Thu Feb 25 2021 Neal Gompa <ngompa13@gmail.com>
- Ensure that a repository configuration package is installed
  for Micro DNF or PackageKit patterns
* Sun Feb 21 2021 Neal Gompa <ngompa13@gmail.com>
- Split base pattern into separate patterns for Zypper, Micro DNF, and PackageKit
- Make GNOME and KDE Plasma patterns require PackageKit pattern
* Tue Jan 26 2021 Thorsten Kukuk <kukuk@suse.com>
- Use user(nobody) and group(nobody)
* Tue Jan 26 2021 Fabian Vogt <fvogt@suse.com>
- Drop autofs and nfs-client requirements, not commonly needed
* Tue Jan 26 2021 Thorsten Kukuk <kukuk@suse.com>
- Sync with openSUSE Tumleweed base pattern
- Add busybox
- Cleanup comments from last submission
* Wed Jan 20 2021 Syds Bearda <sydsb@opensuse.org>
- Moved unzip and wget from gnome desktop pattern to common desktop pattern
- add bash-completion, nfs-client and autofs to common desktop pattern for beginner users
- remove kdeconnect-kde from kde desktop pattern as not necessary for every install
* Tue Dec  8 2020 Frederic Crozat <fcrozat@suse.com>
- Ensure gnome-session-wayland is pulled by GNOME desktop pattern.
* Thu Dec  3 2020 Fabian Vogt <fvogt@suse.com>
- Add desktop-common pattern for packages common to GNOME and KDE
  patterns
- Some small cleanups, also because of the source formatter...
- Use proper icons for desktop patterns
- Switch the KDE pattern from plasma5-pk-updates to discover-notifier
  and add plasma-browser-integration
* Wed Nov 25 2020 Fabian Vogt <fvogt@suse.com>
- Add udisks2 and upower to the Plasma desktop pattern
* Tue Nov 17 2020 Dario Faggioli <dfaggioli@suse.com>
- GNOME: encrypt/decript files from Nautilus
  * we need both the extension and the package providing
    /usr/bin/seahorse-daemon
  * Seahorse, the app, is _not_ installed as it's available on
    flathub
* Tue Nov 17 2020 Dario Faggioli <dfaggioli@suse.com>
- GNOME pattern package changes:
  * drop file roller RPM as there is org.gnome.FileRoller
  * add some packages that I've (as well as most users that have
    tried MicroOS desktop recently) found useful during initial
    setup
  * while there, update a comment about using Requires vs. Recommends
* Mon Oct 19 2020 Thorsten Kukuk <kukuk@suse.com>
- Add cockpit pattern
- Remove more optional SELinux packages from default install
* Fri Oct 16 2020 Neal Gompa <ngompa13@gmail.com>
- GNOME desktop pattern:
  + Add a dependency for adwaita-icon-theme so GNOME icons show up
* Fri Oct 16 2020 Thorsten Kukuk <kukuk@suse.com>
- Remove restorecond from the selinux pattern
* Mon Oct 12 2020 Thorsten Kukuk <kukuk@suse.com>
- Make SELinux pattern visible
- Remove caasp compat provides/obsoletes
* Sun Oct 11 2020 Dario Faggioli <dfaggioli@suse.com>
- GNOME desktop pattern:
  * add cups, so that printers can be added
  * add some common printer driver
* Sun Oct 11 2020 Dario Faggioli <dfaggioli@suse.com>
- GNOME desktop pattern:
  * group font packages together
* Sun Oct 11 2020 Dario Faggioli <dfaggioli@suse.com>
- GNOME desktop pattern:
  * add udisks2 and gvfs-backends, so that, in Nautilus, Trash
    works in Nautilus, USB sticks appears when inserted and can
    ben (auto)mounted and the various BTRFS subvolumes are handled
    better (they're not shown as separate volumes, which was pretty
    annoying and cumbersome)
* Thu Oct  8 2020 Thorsten Kukuk <kukuk@suse.com>
- Add container-selinux and selinux-policy-targeted policy packages
  to selinux pattern
- Add policycoreutils-python-utils to media
* Thu Sep  3 2020 Thorsten Kukuk <kukuk@suse.com>
- Remove vim as we use now vim-small
* Wed Sep  2 2020 Thorsten Kukuk <kukuk@suse.com>
- Add lvm2 and nvme-cli to the medium as YaST may need them
  [bsc#1175841]
* Fri Jul 31 2020 Dario Faggioli <dfaggioli@suse.com>
- GNOME desktop pattern:
  * useful tool, not available as flatpak (gnome-usage)
  * packages necessary for using, e.g., a bluetooth headset
  * packages necessary if one wants thumbnails in nautilus
  * make GNOME keyring fully work (gcr-ssh-askpass)
* Fri Jul 31 2020 Thorsten Kukuk <kukuk@suse.com>
- Add xfsprogs to the media else YaST2 can become very unhappy.
* Thu Jul 30 2020 Thorsten Kukuk <kukuk@suse.com>
- Remove explicit cracklib dictionary, instead add pam_pwquality
  to the media.
* Mon Jul 27 2020 Thorsten Kukuk <kukuk@suse.com>
- Re-add kernel-firmware back to the DVDs [bsc#1174521]
* Wed Jun 24 2020 Ludwig Nussel <lnussel@suse.de>
- openSUSE-MicroOS-release -> MicroOS-release
* Fri Jun 19 2020 Ludwig Nussel <lnussel@suse.de>
- further microos_base overhaul:
  * move audit to default pattern where systemd-logger is too. That
    allows to have appliances without disk logging by default
  * use vim-small instead of nano
  * drop kubic-locale-archive, glibc-locale-base has the required
    C and en_US locales.
  * drop parted, system-group-wheel, terminfo, vlan, xfsprogs
  * move hwinfo to hardware pattern
  * explicitly require curl, hostname and iproute2. curl is
    indirectly needed by igition, hostname and iproute2 is
    considered core.
- microos_hardware
  * remove explicit kernel requirements, this allows yast to
    decide about the kernel (jsc#PM-1968)
* Mon Jun 15 2020 Ludwig Nussel <lnussel@suse.de>
- tidy up package list of microos_base
* Mon May  4 2020 Ludwig Nussel <lnussel@suse.de>
- require issue-generator
- requires update_test pattern during beta test of stable distro. Need to
  require it as recommends is turned off for MicroOS installations.
* Thu Apr 23 2020 Ludwig Nussel <lnussel@suse.de>
- base pattern:
  * remove pciutils, pulls in pciutils-ids which pulls in perl. In Factory
    pciutils-ids has been replaced by hwdata.
  * use bootloader pattern
* Thu Apr 23 2020 Christian Dywan <cdywan@suse.com>
- Drop Firefox package in favor of org.mozilla.firefox on FlatHub
* Thu Apr 16 2020 Thorsten Kukuk <kukuk@suse.com>
- Install branding-openSUSE meta package
- Put apparmor-utils only on DVD, but don't install by default
  (follow Tumbleweed)
* Wed Mar 11 2020 Bjørn Lie <bjorn.lie@gmail.com>
- Drop NetworkManager-applet Requires: We do not need this at all
  inside gnome-shell, we have had built-in tools for a long time.
* Wed Feb 12 2020 Frederic Crozat <fcrozat@suse.com>
- Move fcoe-utils and irqbalance to hardware pattern, not useful
  on guest install.
* Wed Feb 12 2020 Richard Brown <rbrown@suse.com>
- Introduce MicroOS Desktop patterns [boo#1163453]
* Tue Nov 26 2019 Thorsten Kukuk <kukuk@suse.com>
- Install libnss_usrfiles2 by default for /usr/etc support
* Wed Nov 13 2019 kukuk@suse.de
- Don't install open-iscsi by default [bsc#1156660]
* Tue Oct  1 2019 kukuk@suse.de
- Enable armv7
* Wed Sep 11 2019 kukuk@suse.de
- Replace vim with nano (less dependency, default what others are
  using, including in documentation)
* Mon Aug 12 2019 kukuk@suse.de
- MicroOS base: remove update-checker, the only on openSUSE usefull
  functionality (orphaned packages) does not work due a zypper bug.
* Fri Aug  9 2019 kukuk@suse.de
- Add zypper-needs-restarting to MicroOS base pattern
* Wed Jun  5 2019 kukuk@suse.de
- Add bcache-tools to DVD [bsc#1136815]
* Fri May 10 2019 kukuk@suse.de
- Add multipath-tools to DVD for the case the installer needs it
* Wed May  8 2019 Richard Brown <rbrown@suse.com>
- Add wpa_supplicant to media [boo#1134429]
* Mon May  6 2019 kukuk@suse.de
- Add cryptsetup to media [bsc#1134139]
* Fri Apr 26 2019 Richard Brown <rbrown@suse.com>
- Remove salt-master and -minion from onlyDVD pattern
  Not needed for MicroOS, will be used in Kubic via system_roles
* Thu Apr 11 2019 Richard Brown <rbrown@suse.com>
- Correctly obsolete patterns-caasp-* version 4.0
* Thu Apr  4 2019 Richard Brown <rbrown@suse.com>
- Require tftpboot-installation for MicroOS, not Tumbleweed-Kubic
* Wed Apr  3 2019 Richard Brown <rbrown@suse.com>
- Add pattern-microos-basesystem pattern to provide pattern() = basesystem
* Tue Apr  2 2019 Fabian Vogt <fvogt@suse.com>
- Fix "additonal" typos
- Fix accidental use of Provides instead of Requires
* Mon Apr  1 2019 Richard Brown <rbrown@suse.com>
- onlyDVD patterns no longer require container runtime patterns
* Wed Mar 27 2019 kukuk@suse.de
- Remove fipscheck from base pattern
* Wed Mar 20 2019 Jan Engelhardt <jengelh@inai.de>
- Compact %%install section.
* Mon Mar 18 2019 Richard Brown <rbrown@suse.com>
- Initial version
